@@ -85,15 +85,6 @@ typedef enum
   N_SPIN_DOWN_HDDS
 } XfpmSpindownRequest;
 
-typedef enum
-{
-  SHOW_ICON_ALWAYS,
-  SHOW_ICON_WHEN_BATTERY_PRESENT,
-  SHOW_ICON_WHEN_BATTERY_CHARGING_DISCHARGING,
-  SHOW_ICON_NEVER,
-  N_SHOW_ICONS
-} XfpmShowIcon;
-
 typedef enum
 {
   PANEL_LABEL_NONE,
