@@ -1,4 +1,4 @@
- /*
+/*
  * * Copyright (C) 2008-2011 Ali <aliov@xfce.org>
  *
  * Licensed under the GNU General Public License Version 2
@@ -21,7 +21,7 @@
 #ifndef __XFPM_ENUM_H
 #define __XFPM_ENUM_H
 
-#include <gtk/gtk.h>
+#include <glib.h>
 
 G_BEGIN_DECLS
 
@@ -35,23 +35,24 @@ typedef enum
 
 typedef enum
 {
-  LID_KEY   	        	= (1 << 0),
-  BRIGHTNESS_KEY_UP   	= (1 << 1),
-  BRIGHTNESS_KEY_DOWN  	= (1 << 2),
-  SLEEP_KEY 	        	= (1 << 3),
-  HIBERNATE_KEY	        = (1 << 4),
-  POWER_KEY 	        	= (1 << 5),
-  KBD_BRIGHTNESS_KEY_UP	= (1 << 6),
-  KBD_BRIGHTNESS_KEY_DOWN	= (1 << 7),
-  BATTERY_KEY                 = (1 << 8)
+  LID_KEY = (1 << 0),
+  BRIGHTNESS_KEY_UP = (1 << 1),
+  BRIGHTNESS_KEY_DOWN = (1 << 2),
+  SLEEP_KEY = (1 << 3),
+  HIBERNATE_KEY = (1 << 4),
+  POWER_KEY = (1 << 5),
+  KBD_BRIGHTNESS_KEY_UP = (1 << 6),
+  KBD_BRIGHTNESS_KEY_DOWN = (1 << 7),
+  KBD_BRIGHTNESS_CYCLE = (1 << 8),
+  BATTERY_KEY = (1 << 9)
 } XfpmKeys;
 
 typedef enum
 {
-  CPU_UNKNOWN         = (1 << 0),
-  CPU_POWERSAVE	= (1 << 1),
-  CPU_ONDEMAND	= (1 << 2),
-  CPU_PERFORMANCE	= (1 << 3)
+  CPU_UNKNOWN = (1 << 0),
+  CPU_POWERSAVE = (1 << 1),
+  CPU_ONDEMAND = (1 << 2),
+  CPU_PERFORMANCE = (1 << 3)
 } XfpmCpuGovernor;
 
 G_END_DECLS
