@@ -263,6 +263,7 @@ get_device_icon_name (UpClient *upower,
   else if (g_strcmp0 (upower_icon, "") != 0)
     icon_name = g_strndup (upower_icon, icon_base_length);
 
+  g_free (upower_icon);
   return icon_name;
 }
 
@@ -274,7 +275,7 @@ get_device_description (UpClient *upower,
   gchar *est_time_str = NULL;
   guint type = 0, state = 0;
   gchar *model = NULL, *vendor = NULL;
-  gboolean present, online;
+  gboolean present, online, power_supply;
   gdouble percentage;
   guint64 time_to_empty, time_to_full;
 
@@ -289,6 +290,7 @@ get_device_description (UpClient *upower,
                 "time-to-empty", &time_to_empty,
                 "time-to-full", &time_to_full,
                 "online", &online,
+                "power-supply", &power_supply,
                 NULL);
 
   if (is_display_device (upower, device))
@@ -331,7 +333,7 @@ get_device_description (UpClient *upower,
 
   if (state == UP_DEVICE_STATE_FULLY_CHARGED)
   {
-    if (time_to_empty > 0)
+    if (time_to_empty > 0 && !power_supply)
     {
       est_time_str = xfpm_battery_get_time_string (time_to_empty);
       tip = g_strdup_printf (_("<b>%s %s</b>\nFully charged - %s remaining"),
