@@ -25,47 +25,50 @@
  */
 
 #ifdef HAVE_CONFIG_H
-#include <config.h>
+#include "config.h"
 #endif
 
 #include "scalemenuitem.h"
 
-#include <gdk/gdk.h>
 #include <gdk/gdkkeysyms.h>
 
-/* for DBG/TRACE */
-#include <libxfce4util/libxfce4util.h>
+
+
+static gboolean
+scale_menu_item_button_press_event (GtkWidget *menuitem,
+                                    GdkEventButton *event);
+static gboolean
+scale_menu_item_button_release_event (GtkWidget *menuitem,
+                                      GdkEventButton *event);
+static gboolean
+scale_menu_item_motion_notify_event (GtkWidget *menuitem,
+                                     GdkEventMotion *event);
+static gboolean
+scale_menu_item_grab_broken (GtkWidget *menuitem,
+                             GdkEventGrabBroken *event);
+static void
+scale_menu_item_parent_set (GtkWidget *item,
+                            GtkWidget *previous_parent);
+static void
+update_packing (ScaleMenuItem *self);
 
 
 
-static gboolean scale_menu_item_button_press_event      (GtkWidget          *menuitem,
-                                                         GdkEventButton     *event);
-static gboolean scale_menu_item_button_release_event    (GtkWidget          *menuitem,
-                                                         GdkEventButton     *event);
-static gboolean scale_menu_item_motion_notify_event     (GtkWidget          *menuitem,
-                                                         GdkEventMotion     *event);
-static gboolean scale_menu_item_grab_broken             (GtkWidget          *menuitem,
-                                                         GdkEventGrabBroken *event);
-static void     scale_menu_item_parent_set              (GtkWidget          *item,
-                                                         GtkWidget          *previous_parent);
-static void     update_packing                          (ScaleMenuItem  *    self);
-
-
-
-
-struct _ScaleMenuItemPrivate {
-  GtkWidget            *scale;
-  GtkWidget            *description_label;
-  GtkWidget            *percentage_label;
-  GtkWidget            *vbox;
-  GtkWidget            *hbox;
-  gboolean              grabbed;
-  gboolean              ignore_value_changed;
+struct _ScaleMenuItemPrivate
+{
+  GtkWidget *scale;
+  GtkWidget *description_label;
+  GtkWidget *percentage_label;
+  GtkWidget *vbox;
+  GtkWidget *hbox;
+  gboolean grabbed;
+  gboolean ignore_value_changed;
 };
 
 
 
-enum {
+enum
+{
   SLIDER_GRABBED,
   SLIDER_RELEASED,
   VALUE_CHANGED,
@@ -74,7 +77,6 @@ enum {
 
 
 
-
 static guint signals[LAST_SIGNAL] = { 0 };
 
 G_GNUC_BEGIN_IGNORE_DEPRECATIONS
@@ -85,7 +87,7 @@ G_GNUC_END_IGNORE_DEPRECATIONS
 
 static void
 scale_menu_item_scale_value_changed (GtkRange *range,
-                                     gpointer  user_data)
+                                     gpointer user_data)
 {
   ScaleMenuItem *self = user_data;
   ScaleMenuItemPrivate *priv = scale_menu_item_get_instance_private (self);
@@ -100,14 +102,14 @@ scale_menu_item_scale_value_changed (GtkRange *range,
 static void
 scale_menu_item_class_init (ScaleMenuItemClass *item_class)
 {
-  GObjectClass      *gobject_class =   G_OBJECT_CLASS      (item_class);
-  GtkWidgetClass    *widget_class =    GTK_WIDGET_CLASS    (item_class);
+  GObjectClass *gobject_class = G_OBJECT_CLASS (item_class);
+  GtkWidgetClass *widget_class = GTK_WIDGET_CLASS (item_class);
 
-  widget_class->button_press_event   = scale_menu_item_button_press_event;
+  widget_class->button_press_event = scale_menu_item_button_press_event;
   widget_class->button_release_event = scale_menu_item_button_release_event;
-  widget_class->motion_notify_event  = scale_menu_item_motion_notify_event;
-  widget_class->grab_broken_event    = scale_menu_item_grab_broken;
-  widget_class->parent_set           = scale_menu_item_parent_set;
+  widget_class->motion_notify_event = scale_menu_item_motion_notify_event;
+  widget_class->grab_broken_event = scale_menu_item_grab_broken;
+  widget_class->parent_set = scale_menu_item_parent_set;
 
 
   /**
@@ -159,9 +161,9 @@ scale_menu_item_class_init (ScaleMenuItemClass *item_class)
 static void
 remove_children (GtkContainer *container)
 {
-  GList * children = gtk_container_get_children (container);
-  GList * l;
-  for (l=children; l!=NULL; l=l->next)
+  GList *children = gtk_container_get_children (container);
+  GList *l;
+  for (l = children; l != NULL; l = l->next)
     gtk_container_remove (container, l->data);
   g_list_free (children);
 }
@@ -173,14 +175,9 @@ update_packing (ScaleMenuItem *self)
   GtkWidget *hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
   GtkWidget *vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
 
-  TRACE("entering");
-
-//  hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
-//  vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
-
-  if(priv->hbox)
+  if (priv->hbox)
     remove_children (GTK_CONTAINER (priv->hbox));
-  if(priv->vbox)
+  if (priv->vbox)
   {
     remove_children (GTK_CONTAINER (priv->vbox));
     gtk_container_remove (GTK_CONTAINER (self), priv->vbox);
@@ -192,35 +189,35 @@ update_packing (ScaleMenuItem *self)
   /* add the new layout */
   if (priv->description_label && priv->percentage_label)
   {
-      /* [IC]  Description
-       * [ON]  <----slider----> [percentage]%
-       */
-      gtk_box_pack_start (GTK_BOX (vbox), priv->description_label, FALSE, FALSE, 0);
-      gtk_box_pack_start (GTK_BOX (vbox), priv->hbox, TRUE, TRUE, 0);
-      gtk_box_pack_start (GTK_BOX (hbox), priv->scale, TRUE, TRUE, 0);
-      gtk_box_pack_start (GTK_BOX (hbox), priv->percentage_label, FALSE, FALSE, 0);
+    /* [IC]  Description
+     * [ON]  <----slider----> [percentage]%
+     */
+    gtk_box_pack_start (GTK_BOX (vbox), priv->description_label, FALSE, FALSE, 0);
+    gtk_box_pack_start (GTK_BOX (vbox), priv->hbox, TRUE, TRUE, 0);
+    gtk_box_pack_start (GTK_BOX (hbox), priv->scale, TRUE, TRUE, 0);
+    gtk_box_pack_start (GTK_BOX (hbox), priv->percentage_label, FALSE, FALSE, 0);
   }
   else if (priv->description_label)
   {
-      /* [IC]  Description
-       * [ON]  <----slider---->
-       */
-      gtk_box_pack_start (GTK_BOX (vbox), priv->description_label, FALSE, FALSE, 0);
-      gtk_box_pack_start (GTK_BOX (vbox), priv->hbox, TRUE, TRUE, 0);
-      gtk_box_pack_start (GTK_BOX (hbox), priv->scale, TRUE, TRUE, 0);
+    /* [IC]  Description
+     * [ON]  <----slider---->
+     */
+    gtk_box_pack_start (GTK_BOX (vbox), priv->description_label, FALSE, FALSE, 0);
+    gtk_box_pack_start (GTK_BOX (vbox), priv->hbox, TRUE, TRUE, 0);
+    gtk_box_pack_start (GTK_BOX (hbox), priv->scale, TRUE, TRUE, 0);
   }
   else if (priv->percentage_label)
   {
-      /* [ICON]  <----slider----> [percentage]%  */
-      gtk_box_pack_start (GTK_BOX (vbox), priv->hbox, TRUE, TRUE, 0);
-      gtk_box_pack_start (GTK_BOX (hbox), priv->scale, TRUE, TRUE, 0);
-      gtk_box_pack_start (GTK_BOX (hbox), priv->percentage_label, FALSE, FALSE, 0);
+    /* [ICON]  <----slider----> [percentage]%  */
+    gtk_box_pack_start (GTK_BOX (vbox), priv->hbox, TRUE, TRUE, 0);
+    gtk_box_pack_start (GTK_BOX (hbox), priv->scale, TRUE, TRUE, 0);
+    gtk_box_pack_start (GTK_BOX (hbox), priv->percentage_label, FALSE, FALSE, 0);
   }
   else
   {
-      /* [ICON]  <----slider---->  */
-      gtk_box_pack_start (GTK_BOX (vbox), priv->hbox, TRUE, TRUE, 0);
-      gtk_box_pack_start (GTK_BOX (hbox), priv->scale, TRUE, TRUE, 0);
+    /* [ICON]  <----slider---->  */
+    gtk_box_pack_start (GTK_BOX (vbox), priv->hbox, TRUE, TRUE, 0);
+    gtk_box_pack_start (GTK_BOX (hbox), priv->scale, TRUE, TRUE, 0);
   }
 
   gtk_widget_show_all (priv->vbox);
@@ -235,27 +232,24 @@ scale_menu_item_init (ScaleMenuItem *self)
 }
 
 static gboolean
-scale_menu_item_button_press_event (GtkWidget      *menuitem,
+scale_menu_item_button_press_event (GtkWidget *menuitem,
                                     GdkEventButton *event)
 {
   ScaleMenuItemPrivate *priv = scale_menu_item_get_instance_private (SCALE_MENU_ITEM (menuitem));
   GtkAllocation alloc;
   gint x, y;
 
-  TRACE("entering");
-
   gtk_widget_get_allocation (priv->scale, &alloc);
   gtk_widget_translate_coordinates (menuitem, priv->scale, event->x, event->y, &x, &y);
 
   if (x > 0 && x < alloc.width && y > 0 && y < alloc.height)
-    gtk_widget_event (priv->scale,
-                      ((GdkEvent *)(void*)(event)));
+    gtk_widget_event (priv->scale, (GdkEvent *) event);
 
   if (!priv->grabbed)
-    {
-      priv->grabbed = TRUE;
-      g_signal_emit (menuitem, signals[SLIDER_GRABBED], 0);
-    }
+  {
+    priv->grabbed = TRUE;
+    g_signal_emit (menuitem, signals[SLIDER_GRABBED], 0);
+  }
 
   return TRUE;
 }
@@ -266,21 +260,19 @@ scale_menu_item_button_release_event (GtkWidget *menuitem,
 {
   ScaleMenuItemPrivate *priv = scale_menu_item_get_instance_private (SCALE_MENU_ITEM (menuitem));
 
-  TRACE("entering");
-
-  gtk_widget_event (priv->scale, (GdkEvent*)event);
+  gtk_widget_event (priv->scale, (GdkEvent *) event);
 
   if (priv->grabbed)
-    {
-      priv->grabbed = FALSE;
-      g_signal_emit (menuitem, signals[SLIDER_RELEASED], 0);
-    }
+  {
+    priv->grabbed = FALSE;
+    g_signal_emit (menuitem, signals[SLIDER_RELEASED], 0);
+  }
 
   return TRUE;
 }
 
 static gboolean
-scale_menu_item_motion_notify_event (GtkWidget      *menuitem,
+scale_menu_item_motion_notify_event (GtkWidget *menuitem,
                                      GdkEventMotion *event)
 {
   ScaleMenuItemPrivate *priv = scale_menu_item_get_instance_private (SCALE_MENU_ITEM (menuitem));
@@ -300,9 +292,8 @@ scale_menu_item_motion_notify_event (GtkWidget      *menuitem,
     event->y = y;
   }
 
-  if (priv->grabbed ||
-      (x > 0 && x < alloc.width && y > 0 && y < alloc.height))
-    gtk_widget_event (scale, (GdkEvent*)event);
+  if (priv->grabbed || (x > 0 && x < alloc.width && y > 0 && y < alloc.height))
+    gtk_widget_event (scale, (GdkEvent *) event);
 
   return TRUE;
 }
@@ -313,24 +304,22 @@ scale_menu_item_grab_broken (GtkWidget *menuitem,
 {
   ScaleMenuItemPrivate *priv = scale_menu_item_get_instance_private (SCALE_MENU_ITEM (menuitem));
 
-  TRACE("entering");
-
   GTK_WIDGET_GET_CLASS (priv->scale)->grab_broken_event (priv->scale, event);
 
   return TRUE;
 }
 
 static void
-menu_hidden (GtkWidget        *menu,
+menu_hidden (GtkWidget *menu,
              ScaleMenuItem *scale)
 {
   ScaleMenuItemPrivate *priv = scale_menu_item_get_instance_private (scale);
 
   if (priv->grabbed)
-    {
-      priv->grabbed = FALSE;
-      g_signal_emit (scale, signals[SLIDER_RELEASED], 0);
-    }
+  {
+    priv->grabbed = FALSE;
+    g_signal_emit (scale, signals[SLIDER_RELEASED], 0);
+  }
 }
 
 static void
@@ -341,30 +330,28 @@ scale_menu_item_parent_set (GtkWidget *item,
   GtkWidget *parent;
 
   if (previous_parent)
-    {
-      g_signal_handlers_disconnect_by_func (previous_parent, menu_hidden, item);
-    }
+  {
+    g_signal_handlers_disconnect_by_func (previous_parent, menu_hidden, item);
+  }
 
   parent = gtk_widget_get_parent (item);
 
   if (parent)
-    {
-      g_signal_connect (parent, "hide", G_CALLBACK (menu_hidden), item);
-    }
+  {
+    g_signal_connect (parent, "hide", G_CALLBACK (menu_hidden), item);
+  }
 }
 
 
 
-GtkWidget*
-scale_menu_item_new_with_range (gdouble           min,
-                                gdouble           max,
-                                gdouble           step)
+GtkWidget *
+scale_menu_item_new_with_range (gdouble min,
+                                gdouble max,
+                                gdouble step)
 {
   ScaleMenuItem *scale_item;
   ScaleMenuItemPrivate *priv;
 
-  TRACE("entering");
-
   scale_item = SCALE_MENU_ITEM (g_object_new (TYPE_SCALE_MENU_ITEM, NULL));
 
   priv = scale_menu_item_get_instance_private (scale_item);
@@ -376,14 +363,17 @@ scale_menu_item_new_with_range (gdouble           min,
   g_signal_connect (priv->scale, "value-changed", G_CALLBACK (scale_menu_item_scale_value_changed), scale_item);
   g_object_ref (priv->scale);
   gtk_widget_set_size_request (priv->scale, 100, -1);
-  gtk_range_set_inverted (GTK_RANGE(priv->scale), FALSE);
-  gtk_scale_set_draw_value (GTK_SCALE(priv->scale), FALSE);
+  gtk_range_set_inverted (GTK_RANGE (priv->scale), FALSE);
+  gtk_scale_set_draw_value (GTK_SCALE (priv->scale), FALSE);
 
   update_packing (scale_item);
 
-  gtk_widget_add_events (GTK_WIDGET(scale_item), GDK_SCROLL_MASK|GDK_POINTER_MOTION_MASK|GDK_BUTTON_MOTION_MASK);
+  gtk_widget_add_events (GTK_WIDGET (scale_item),
+                         GDK_SCROLL_MASK
+                           | GDK_POINTER_MOTION_MASK
+                           | GDK_BUTTON_MOTION_MASK);
 
-  return GTK_WIDGET(scale_item);
+  return GTK_WIDGET (scale_item);
 }
 
 /**
@@ -394,7 +384,7 @@ scale_menu_item_new_with_range (gdouble           min,
  *
  * Return Value: (transfer none)
  **/
-GtkWidget*
+GtkWidget *
 scale_menu_item_get_scale (ScaleMenuItem *menuitem)
 {
   ScaleMenuItemPrivate *priv;
@@ -414,7 +404,7 @@ scale_menu_item_get_scale (ScaleMenuItem *menuitem)
  *
  * Return Value: The label text.
  **/
-const gchar*
+const gchar *
 scale_menu_item_get_description_label (ScaleMenuItem *menuitem)
 {
   ScaleMenuItemPrivate *priv;
@@ -434,7 +424,7 @@ scale_menu_item_get_description_label (ScaleMenuItem *menuitem)
  *
  * Return Value: The label text.
  **/
-const gchar*
+const gchar *
 scale_menu_item_get_percentage_label (ScaleMenuItem *menuitem)
 {
   ScaleMenuItemPrivate *priv;
@@ -456,7 +446,7 @@ scale_menu_item_get_percentage_label (ScaleMenuItem *menuitem)
  **/
 void
 scale_menu_item_set_description_label (ScaleMenuItem *menuitem,
-                                       const gchar      *label)
+                                       const gchar *label)
 {
   ScaleMenuItemPrivate *priv;
 
@@ -465,28 +455,28 @@ scale_menu_item_set_description_label (ScaleMenuItem *menuitem,
   priv = scale_menu_item_get_instance_private (menuitem);
 
   if (label == NULL && priv->description_label)
-    {
-      /* remove label */
-      g_object_unref (priv->description_label);
-      priv->description_label = NULL;
-      return;
-    }
+  {
+    /* remove label */
+    g_object_unref (priv->description_label);
+    priv->description_label = NULL;
+    return;
+  }
 
   if (priv->description_label && label)
-    {
-      gtk_label_set_markup (GTK_LABEL (priv->description_label), label);
-    }
-  else if(label)
-    {
-      /* create label */
-      priv->description_label = gtk_label_new (NULL);
-      gtk_label_set_markup (GTK_LABEL (priv->description_label), label);
+  {
+    gtk_label_set_markup (GTK_LABEL (priv->description_label), label);
+  }
+  else if (label)
+  {
+    /* create label */
+    priv->description_label = gtk_label_new (NULL);
+    gtk_label_set_markup (GTK_LABEL (priv->description_label), label);
 
-      /* align left */
-      gtk_widget_set_halign (GTK_WIDGET (priv->description_label), GTK_ALIGN_START);
-    }
+    /* align left */
+    gtk_widget_set_halign (GTK_WIDGET (priv->description_label), GTK_ALIGN_START);
+  }
 
-    update_packing (menuitem);
+  update_packing (menuitem);
 }
 
 
@@ -500,7 +490,7 @@ scale_menu_item_set_description_label (ScaleMenuItem *menuitem,
  **/
 void
 scale_menu_item_set_percentage_label (ScaleMenuItem *menuitem,
-                                      const gchar      *label)
+                                      const gchar *label)
 {
   ScaleMenuItemPrivate *priv;
 
@@ -509,26 +499,26 @@ scale_menu_item_set_percentage_label (ScaleMenuItem *menuitem,
   priv = scale_menu_item_get_instance_private (menuitem);
 
   if (label == NULL && priv->percentage_label)
-    {
-      /* remove label */
-      g_object_unref (priv->percentage_label);
-      priv->percentage_label = NULL;
-      return;
-    }
+  {
+    /* remove label */
+    g_object_unref (priv->percentage_label);
+    priv->percentage_label = NULL;
+    return;
+  }
 
   if (priv->percentage_label && label)
-    {
-      gtk_label_set_text (GTK_LABEL (priv->percentage_label), label);
-    }
-  else if(label)
-    {
-      /* create label */
-      priv->percentage_label = gtk_label_new (label);
-      /* align left */
-      gtk_widget_set_halign (GTK_WIDGET (priv->percentage_label), GTK_ALIGN_START);
-    }
+  {
+    gtk_label_set_text (GTK_LABEL (priv->percentage_label), label);
+  }
+  else if (label)
+  {
+    /* create label */
+    priv->percentage_label = gtk_label_new (label);
+    /* align left */
+    gtk_widget_set_halign (GTK_WIDGET (priv->percentage_label), GTK_ALIGN_START);
+  }
 
-    update_packing (menuitem);
+  update_packing (menuitem);
 }
 
 
@@ -540,7 +530,7 @@ scale_menu_item_set_percentage_label (ScaleMenuItem *menuitem,
  */
 void
 scale_menu_item_set_value (ScaleMenuItem *item,
-                           gdouble        value)
+                           gdouble value)
 {
   ScaleMenuItemPrivate *priv = scale_menu_item_get_instance_private (item);
 
