@@ -20,27 +20,32 @@
  */
 
 #ifdef HAVE_CONFIG_H
-#include <config.h>
+#include "config.h"
 #endif
 
 #include "xfpm-dpms.h"
 #include "xfpm-xfconf.h"
+
 #include "common/xfpm-config.h"
 #include "common/xfpm-debug.h"
 
 #ifdef ENABLE_X11
-#include <gdk/gdkx.h>
 #include "xfpm-dpms-x11.h"
+
+#include <gdk/gdkx.h>
 #endif
+
 #ifdef ENABLE_WAYLAND
-#include <gdk/gdkwayland.h>
 #include "xfpm-dpms-wayland.h"
+
+#include <gdk/gdkwayland.h>
 #endif
 
-#define get_instance_private(instance) ((XfpmDpmsPrivate *) \
-  xfpm_dpms_get_instance_private (XFPM_DPMS (instance)))
+#define get_instance_private(instance) \
+  ((XfpmDpmsPrivate *) xfpm_dpms_get_instance_private (XFPM_DPMS (instance)))
 
-static void       xfpm_dpms_finalize       (GObject       *object);
+static void
+xfpm_dpms_finalize (GObject *object);
 
 typedef struct _XfpmDpmsPrivate
 {
@@ -96,7 +101,7 @@ refresh (XfpmDpms *dpms)
     return;
   }
 
-  g_object_get (priv->conf, DPMS_ENABLED_CFG, &enabled, NULL);
+  g_object_get (priv->conf, DPMS_ENABLED, &enabled, NULL);
   if (!enabled)
   {
     XFPM_DPMS_GET_CLASS (dpms)->set_enabled (dpms, FALSE);
@@ -104,13 +109,14 @@ refresh (XfpmDpms *dpms)
   }
 
   g_object_get (priv->conf,
-                priv->on_battery ? ON_BATT_DPMS_SLEEP : ON_AC_DPMS_SLEEP, &sleep_timeout,
-                priv->on_battery ? ON_BATT_DPMS_OFF : ON_AC_DPMS_OFF, &off_timeout,
+                priv->on_battery ? DPMS_ON_BATTERY_SLEEP : DPMS_ON_AC_SLEEP, &sleep_timeout,
+                priv->on_battery ? DPMS_ON_BATTERY_OFF : DPMS_ON_AC_OFF, &off_timeout,
                 NULL);
   g_object_get (G_OBJECT (priv->conf), DPMS_SLEEP_MODE, &sleep_mode, NULL);
 
   XFPM_DPMS_GET_CLASS (dpms)->set_enabled (dpms, TRUE);
-  XFPM_DPMS_GET_CLASS (dpms)->set_timeouts (dpms, g_strcmp0 (sleep_mode, "Standby") == 0, sleep_timeout * 60, off_timeout * 60);
+  XFPM_DPMS_GET_CLASS (dpms)->set_timeouts (dpms, g_strcmp0 (sleep_mode, "Standby") == 0,
+                                            sleep_timeout * 60, off_timeout * 60);
 
   g_free (sleep_mode);
 }
