@@ -25,21 +25,22 @@
 
 G_BEGIN_DECLS
 
-#define XFPM_ERROR      (xfpm_get_error_quark ())
+#define XFPM_ERROR (xfpm_get_error_quark ())
 
 
 typedef enum
 {
-    XFPM_ERROR_UNKNOWN = 0,
-    XFPM_ERROR_PERMISSION_DENIED,
-    XFPM_ERROR_NO_HARDWARE_SUPPORT,
-    XFPM_ERROR_COOKIE_NOT_FOUND,
-    XFPM_ERROR_INVALID_ARGUMENTS,
-    XFPM_ERROR_SLEEP_FAILED
+  XFPM_ERROR_UNKNOWN = 0,
+  XFPM_ERROR_PERMISSION_DENIED,
+  XFPM_ERROR_NO_HARDWARE_SUPPORT,
+  XFPM_ERROR_COOKIE_NOT_FOUND,
+  XFPM_ERROR_INVALID_ARGUMENTS,
+  XFPM_ERROR_SLEEP_FAILED
 
 } XfpmError;
 
-GQuark  xfpm_get_error_quark (void);
+GQuark
+xfpm_get_error_quark (void);
 
 
 G_END_DECLS
