@@ -18,10 +18,17 @@
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  */
 #ifdef HAVE_CONFIG_H
-#include <config.h>
+#include "config.h"
 #endif
 
+#include "xfpm-suspend.h"
+
+#include "common/xfpm-common.h"
+#include "common/xfpm-debug.h"
+
+#include <libxfce4util/libxfce4util.h>
 #include <stdio.h>
+
 #ifdef HAVE_STDLIB_H
 #include <stdlib.h>
 #endif
@@ -41,24 +48,19 @@
 #include <errno.h>
 #endif
 
-#include <libxfce4util/libxfce4util.h>
-
-#include "xfpm-common.h"
-#include "xfpm-debug.h"
-#include "xfpm-suspend.h"
-
-
 
 #ifdef BACKEND_TYPE_FREEBSD
 static gchar *
-get_string_sysctl (GError **err, const gchar *format, ...)
+get_string_sysctl (GError **err,
+                   const gchar *format,
+                   ...)
 {
   va_list args;
   gchar *name;
   size_t value_len;
   gchar *str = NULL;
 
-  g_return_val_if_fail(format != NULL, FALSE);
+  g_return_val_if_fail (format != NULL, FALSE);
 
   va_start (args, format);
   name = g_strdup_vprintf (format, args);
@@ -70,16 +72,17 @@ get_string_sysctl (GError **err, const gchar *format, ...)
 
     if (sysctlbyname (name, str, &value_len, NULL, 0) == 0)
       str[value_len] = 0;
-    else {
+    else
+    {
       g_free (str);
       str = NULL;
     }
   }
 
   if (!str)
-    g_set_error (err, 0, 0, "%s", g_strerror(errno));
+    g_set_error (err, 0, 0, "%s", g_strerror (errno));
 
-  g_free(name);
+  g_free (name);
 
   return str;
 }
@@ -88,11 +91,10 @@ static gboolean
 freebsd_supports_sleep_state (const gchar *state)
 {
   gboolean ret = FALSE;
-  gchar *sleep_states;
+  gchar *sleep_states = get_string_sysctl (NULL, "hw.acpi.supported_sleep_state");
 
-  sleep_states = get_string_sysctl (NULL, "hw.acpi.supported_sleep_state");
-
-  if (sleep_states != NULL) {
+  if (sleep_states != NULL)
+  {
     if (strstr (sleep_states, state) != NULL)
       ret = TRUE;
   }
@@ -162,6 +164,22 @@ xfpm_suspend_can_hibernate (void)
   return FALSE;
 }
 
+gboolean
+xfpm_suspend_can_hybrid_sleep (void)
+{
+#ifdef BACKEND_TYPE_FREEBSD
+  return TRUE;
+#endif
+#ifdef BACKEND_TYPE_LINUX
+  return linux_supports_sleep_state ("suspend-hybrid");
+#endif
+#ifdef BACKEND_TYPE_OPENBSD
+  return TRUE;
+#endif
+
+  return FALSE;
+}
+
 gboolean
 xfpm_suspend_try_action (XfpmActionType type)
 {
@@ -174,6 +192,8 @@ xfpm_suspend_try_action (XfpmActionType type)
     action = "suspend";
   else if (type == XFPM_HIBERNATE)
     action = "hibernate";
+  else if (type == XFPM_HYBRID_SLEEP)
+    action = "hybrid-sleep";
   else
     return FALSE;
 
